@@ -19,7 +19,9 @@ def send_verification_code_via_email(user, code):
     user_email_address = getattr(user, 'first_name', None)
     regex = r'\b[A-Za-z0-9._%+-]+@[A-Za-z0-9.-]+\.[A-Z|a-z]{2,}\b'
     if not re.fullmatch(regex, user_email_address):
-        raise CodeSendingFailed(_("No e-mail address known"))
+        user_email_address = getattr(user, 'email', None)
+        if not re.fullmatch(regex, user_email_address):
+            raise CodeSendingFailed(_("No e-mail address known"))
 
     subject_template = _(
         api_settings.EMAIL_SENDER_SUBJECT_OVERRIDE or
